==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/DataLegendStylingColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingColumnEventArgsDescription } from "./DataLegendStylingColumnEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendStylingColumnEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendStylingColumnEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendStylingColumnEventArgsDescriptionMetadata.a == null) {
                DataLegendStylingColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendStylingColumnEventArgsDescriptionMetadata.c(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendStylingColumnEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnIndex", "Number:int");
            a.item("SeriesIndex", "Number:int");
            a.item("SeriesTitle", "String");
            a.item("ValueOriginal", "Number:double");
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberLabel", "String");
            a.item("ValueAbbreviation", "ExportedType:string:DataAbbreviationMode");
            a.item("ValueAbbreviation@names", "Auto;Independent;Shared;Kilo;Million;Billion;Trillion;Quadrillion;Unset;None");
            a.item("LabelText", "String");
            a.item("UnitsText", "String");
            a.item("ValueText", "String");
            a.item("LabelTextColor", "Brush");
            a.item("UnitsTextColor", "Brush");
            a.item("ValueTextColor", "Brush");
        }
        static d(a) {
            DataLegendStylingColumnEventArgsDescriptionMetadata.b(a);
            a.ad("DataLegendStylingColumnEventArgs", () => new DataLegendStylingColumnEventArgsDescription());
            a.ac("DataLegendStylingColumnEventArgs", DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendStylingColumnEventArgsDescriptionMetadata.$t = markType(DataLegendStylingColumnEventArgsDescriptionMetadata, 'DataLegendStylingColumnEventArgsDescriptionMetadata');
    DataLegendStylingColumnEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingColumnEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/DataLegendStylingColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingColumnEventArgsDescription } from "./DataLegendStylingColumnEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendStylingColumnEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendStylingColumnEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendStylingColumnEventArgsDescriptionMetadata.a == null) {
                DataLegendStylingColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendStylingColumnEventArgsDescriptionMetadata.c(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendStylingColumnEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnIndex", "Number:int");
            a.item("SeriesIndex", "Number:int");
            a.item("SeriesTitle", "String");
            a.item("ValueOriginal", "Number:double");
            a.item("ValueMemberPath", "String");
            a.item("ValueMemberLabel", "String");
            a.item("ValueAbbreviation", "ExportedType:string:DataAbbreviationMode");
            a.item("ValueAbbreviation@names", "Auto;Independent;Shared;Kilo;Million;Billion;Trillion;Quadrillion;Unset;None");
            a.item("LabelText", "String");
            a.item("UnitsText", "String");
            a.item("ValueText", "String");
            a.item("LabelTextColor", "Brush");
            a.item("UnitsTextColor", "Brush");
            a.item("ValueTextColor", "Brush");
            a.item("GroupName", "String");
        }
        static d(a) {
            DataLegendStylingColumnEventArgsDescriptionMetadata.b(a);
            a.ae("DataLegendStylingColumnEventArgs", () => new DataLegendStylingColumnEventArgsDescription());
            a.ad("DataLegendStylingColumnEventArgs", DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendStylingColumnEventArgsDescriptionMetadata.$t = markType(DataLegendStylingColumnEventArgsDescriptionMetadata, 'DataLegendStylingColumnEventArgsDescriptionMetadata');
    DataLegendStylingColumnEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingColumnEventArgsDescriptionMetadata;
})();
